==> calamares-settings-solydxk_4.12%2Br13.tar.xz: source/ts/calamares-solydxk_sr.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="sr" sourcelanguage="en_US">
<context>
    <name>show</name>
    <message>
        <location filename="../calamares/branding/solydxk/show.qml" line="40"/>
        <source>&lt;h3&gt;Thank you for choosing SolydXK&lt;/h3&gt;&lt;br /&gt;You&apos;ve chosen a Linux distribution that is:&lt;br /&gt;&lt;ul&gt;&lt;li&gt;Secure and stable&lt;/li&gt;&lt;li&gt;Fast and responsive&lt;/li&gt;&lt;li&gt;Desktop-ready&lt;/li&gt;&lt;/ul&gt;&lt;br /&gt;Enjoy this new release and thank you for choosing SolydXK.&lt;br /&gt;&lt;br /&gt;The installation takes 15-30 minutes, depending on your settings.</source>
        <translation>&lt;h3&gt;Хвала што сте изабрали СолидИксК&lt;/h3&gt;&lt;br /&gt;Изабрали сте Линукс дистрибуцију која је:&lt;br /&gt;&lt;ul&gt;&lt;li&gt;Сигурна и стабилна&lt;/li&gt;&lt;li&gt;Брза и агилна&lt;/li&gt;&lt;li&gt;Спремна за графичко корисничко сучеље&lt;/li&gt;&lt;/ul&gt;&lt;br /&gt;Уживајте у новом издању и хвала што сте изабрали СолидИксК.&lt;br /&gt;&lt;br /&gt;Инсталација траје 15-30 минута, зависно од ваших поставки.</translation>
    </message>
    <message>
        <location filename="../calamares/branding/solydxk/show.qml" line="61"/>
        <source>&lt;h3&gt;Standing on the shoulders of Giants&lt;/h3&gt;&lt;br /&gt;SolydXK is a Debian-based GNU/Linux distribution derived from and compatible with Debian.&lt;br /&gt;&lt;br /&gt;SolydXK uses either the lightweight Xfce desktop for SolydX or the highly configurable and stunningly appealing KDE desktop for SolydK.&lt;br /&gt;&lt;br /&gt;Our innovations, the rapid development of Debian and the huge Debian package selection make SolydXK one of the most attractive desktop operating systems available to home users.</source>
        <translation>&lt;h3&gt;Стојећи на раменима џинова&lt;/h3&gt;&lt;br /&gt;СолидИксК је дистрибуција која је проистекла из Дебијан ГНУ/Линукс дистрибуције и потпуно је са њом компатибилна.&lt;br /&gt;&lt;br /&gt;СолидИксК користи или лагано ИксФЦЕ окружење за СоликИкс или фантастично КДЕ окружење за СолидК.&lt;br /&gt;&lt;br /&gt;Наше иновације, активан развој Дебијана и огроман избор Дебијанових пакета чине СолидИксК једним од најпривлачнијих оперативних система доступних кућним корисницима.</translation>
    </message>
    <message>
        <location filename="../calamares/branding/solydxk/show.qml" line="81"/>
        <source>&lt;h3&gt;Out of the box&lt;/h3&gt;&lt;br /&gt;Firefox, Thunderbird, and LibreOffice come pre-installed in SolydXK, so you can get started immediately with the desktop and the Internet.&lt;br /&gt;&lt;br /&gt;Unlike other Linux distributions SolydXK is also ready to play your music, internet videos and more.&lt;br /&gt;&lt;br /&gt;A wide variety of software can be installed with a click of the mouse.&lt;br /&gt;&lt;br /&gt;SolydXK is compatible with most popular file formats such as: docx, xlsx, doc, xls, pdf, zip, rar, mp3, mpg, and many more.</source>
        <translation>&lt;h3&gt;Спреман по инсталацији&lt;/h3&gt;&lt;br /&gt;Фајерфокс, Тандерберд и Либреофис долазе већ инсталирани са СолидИксК-ом па можете одмах почети са радом.&lt;br /&gt;&lt;br /&gt;За разлику од других Линукс дистрибуција, СолидИксК је одмах спреман да пушта музику, видео и још много тога.&lt;br /&gt;&lt;br /&gt;Разни програми се могу инсталирати простим кликом мишем.&lt;br /&gt;&lt;br /&gt;СолидИксК је компатибилан са већином распрострањених формата попут: docx, xlsx, doc, xls, pdf, zip, rar, mp3, mpg и многим другим.</translation>
    </message>
    <message>
        <location filename="../calamares/branding/solydxk/show.qml" line="102"/>
        <source>&lt;h3&gt;Office tools are ready to use as soon as you install SolydXK&lt;/h3&gt;&lt;br /&gt;LibreOffice, a powerful office software suite, comes built into SolydXK.&lt;br /&gt;&lt;br /&gt;LibreOffice is very easy to learn and use.&lt;br /&gt;&lt;br /&gt;You can use it to create letters, presentations and spreadsheets, as well as diagrams and databases.&lt;br /&gt;&lt;br /&gt;LibreOffice uses the standard OpenDocument format and it works with documents from other popular office applications including WordPerfect and Microsoft Office.</source>
        <translation>&lt;h3&gt;Канцеларијски алати су спремни чим инсталирате СолидИксК&lt;/h3&gt;&lt;br /&gt;Либреофис, моћан канцеларијски пакет долази уз СолидИксК.&lt;br /&gt;&lt;br /&gt;Либреофис је веома лак за учење и коришћење.&lt;br /&gt;&lt;br /&gt;Можете га користити за писање, презентације и табеларне калкулације као и за дијаграме и базе података.&lt;br /&gt;&lt;br /&gt;Либреофис користи усвојени формат отвореног документа а ради и са документима популарних канцеларијских програма попут „Ворд перфекта“ и „Мајкрософт офиса“.</translation>
    </message>
    <message>
        <location filename="../calamares/branding/solydxk/show.qml" line="123"/>
        <source>&lt;h3&gt;An alternative to mainstream operating systems&lt;/h3&gt;&lt;br /&gt;SolydXK is easy to use, powerful and configurable.&lt;br /&gt;&lt;br /&gt;SolydXK is safe and stable. Unlike other operating systems, it is not prone to computer viruses or spyware, it does not suffer from disk fragmentation, and it has no registry that requires periodic cleaning.&lt;br /&gt;&lt;br /&gt;SolydXK can detect other operating systems and install itself beside them.You can choose which operating system to launch when you start the computer.</source>
        <translation>&lt;h3&gt;Алтернатива најраспрострањенијим оперативним системима&lt;/h3&gt;&lt;br /&gt;СолидИксК је лак за коришћење, моћан и подесив.&lt;br /&gt;&lt;br /&gt;СолидИксК је сигуран и стабилан. За разлику од других оперативних система, није подложан вирусима или спајверу, не пати од фрагментације диска и нема базу регистара која захтева периодично чишћење.&lt;br /&gt;&lt;br /&gt;СолидИксК може да открије друге оперативне системе и инсталира се поред њих. Можете изабрати који оперативни систем ће се покретати при покретању рачунара.</translation>
    </message>
    <message>
        <location filename="../calamares/branding/solydxk/show.qml" line="143"/>
        <source>&lt;h3&gt;Safe updates&lt;/h3&gt;&lt;br /&gt;Some operating systems make updating your system harder than it really needs to be. SolydXK thinks upgrades should be quick and easy, and then get out of the way.&lt;br /&gt;&lt;br /&gt;The Update Manager sits discreetly in your system tray and lets you know when updates are available. You don&apos;t have to apply updates when you don&apos;t want to. The Update Manager won&apos;t pop up or annoy you in any way.&lt;br /&gt;&lt;br /&gt;All updated files are maintained and closely checked by trusted developers and maintainers.&lt;br /&gt;&lt;br /&gt;All files are stored in special secure repositories for your use.&lt;br /&gt;&lt;br /&gt;The security repository is synchronized daily.</source>
        <translation>&lt;h3&gt;Сигурносне закрпе&lt;/h3&gt;&lt;br /&gt;Неки оперативни системи чине ажурирања система тежим него што би требало. СолидИксК сматра да надоградња треба да буде брза и лака и да не смета.&lt;br /&gt;&lt;br /&gt;Менаџер ажурирања чучи дискретно у системској касети и обавештава вас када су доступна ажурирања. Не морате их применити када то не желите. Менаџер ажурирања неће искакати нити вас нервирати.&lt;br /&gt;&lt;br /&gt;Сви ажурирани фајлови се одржавају и темељно проваравају од стране поузданих програмера.&lt;br /&gt;&lt;br /&gt;Сви фајлови су смештени у посебним сигурним ризницама пакета.&lt;br /&gt;&lt;br /&gt;Сигурносна ризница се синхронизује свакодневно.</translation>
    </message>
    <message>
        <location filename="../calamares/branding/solydxk/show.qml" line="165"/>
        <source>&lt;h3&gt;A great community&lt;/h3&gt;&lt;br /&gt;SolydXK users are happy to share their passion and enthusiasm and are eager to help. Don&apos;t hesitate to ask questions on the forums or to get involved in the community.&lt;br /&gt;&lt;br /&gt;Send us your feedback and tell us about your experience. We&apos;ll listen to your ideas and use them to further improve SolydXK.</source>
        <translation>&lt;h3&gt;Сјајна заједница&lt;/h3&gt;&lt;br /&gt;СолидИксК корисници радо деле своју страст и ентузијазам и желе да помогну. Не оклевајте да поставите питање на форуму нити да се придружите заједници.&lt;br /&gt;&lt;br /&gt;Пошаљите нам ваше утиске и искуства. Саслушаћемо ваше идеје и употребити их у даљем побољшавању СолидИксК-а.</translation>
    </message>
</context>
</TS>

==> calamares-settings-solydxk_4.27%2Br13.tar.xz: source/ts/calamares-solydxk_sr.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="sr" sourcelanguage="en_US">
<context>
    <name>show</name>
    <message>
        <location filename="../calamares/branding/solydxk/show.qml" line="40"/>
        <source>&lt;h3&gt;Thank you for choosing SolydXK&lt;/h3&gt;&lt;br /&gt;You&apos;ve chosen a Linux distribution that is:&lt;br /&gt;&lt;ul&gt;&lt;li&gt;Secure and stable&lt;/li&gt;&lt;li&gt;Fast and responsive&lt;/li&gt;&lt;li&gt;Desktop-ready&lt;/li&gt;&lt;/ul&gt;&lt;br /&gt;Enjoy this new release and thank you for choosing SolydXK.&lt;br /&gt;&lt;br /&gt;The installation takes 15-30 minutes, depending on your settings.</source>
        <translation>&lt;h3&gt;Хвала што сте изабрали СолидИксК&lt;/h3&gt;&lt;br /&gt;Изабрали сте Линукс дистрибуцију која је:&lt;br /&gt;&lt;ul&gt;&lt;li&gt;Сигурна и стабилна&lt;/li&gt;&lt;li&gt;Брза и агилна&lt;/li&gt;&lt;li&gt;Спремна за графичко корисничко сучеље&lt;/li&gt;&lt;/ul&gt;&lt;br /&gt;Уживајте у новом издању и хвала што сте изабрали СолидИксК.&lt;br /&gt;&lt;br /&gt;Инсталација траје 15-30 минута, зависно од ваших поставки.</translation>
    </message>
    <message>
        <location filename="../calamares/branding/solydxk/show.qml" line="61"/>
        <source>&lt;h3&gt;Standing on the shoulders of Giants&lt;/h3&gt;&lt;br /&gt;SolydXK is a Debian-based GNU/Linux distribution derived from and compatible with Debian.&lt;br /&gt;&lt;br /&gt;SolydXK uses either the lightweight Xfce desktop for SolydX or the highly configurable and stunningly appealing KDE desktop for SolydK.&lt;br /&gt;&lt;br /&gt;Our innovations, the rapid development of Debian and the huge Debian package selection make SolydXK one of the most attractive desktop operating systems available to home users.</source>
        <translation>&lt;h3&gt;Стојећи на раменима џинова&lt;/h3&gt;&lt;br /&gt;СолидИксК је дистрибуција која је проистекла из Дебијан ГНУ/Линукс дистрибуције и потпуно је са њом компатибилна.&lt;br /&gt;&lt;br /&gt;СолидИксК користи или лагано ИксФЦЕ окружење за СоликИкс или фантастично КДЕ окружење за СолидК.&lt;br /&gt;&lt;br /&gt;Наше иновације, активан развој Дебијана и огроман избор Дебијанових пакета чине СолидИксК једним од најпривлачнијих оперативних система доступних кућним корисницима.</translation>
    </message>
    <message>
        <location filename="../calamares/branding/solydxk/show.qml" line="81"/>
        <source>&lt;h3&gt;Out of the box&lt;/h3&gt;&lt;br /&gt;Firefox, Thunderbird, and LibreOffice come pre-installed in SolydXK, so you can get started immediately with the desktop and the Internet.&lt;br /&gt;&lt;br /&gt;Unlike other Linux distributions SolydXK is also ready to play your music, internet videos and more.&lt;br /&gt;&lt;br /&gt;A wide variety of software can be installed with a click of the mouse.&lt;br /&gt;&lt;br /&gt;SolydXK is compatible with most popular file formats such as: docx, xlsx, doc, xls, pdf, zip, rar, mp3, mpg, and many more.</source>
        <translation>&lt;h3&gt;Спреман по инсталацији&lt;/h3&gt;&lt;br /&gt;Фајерфокс, Тандерберд и Либреофис долазе већ инсталирани са СолидИксК-ом па можете одмах почети са радом.&lt;br /&gt;&lt;br /&gt;За разлику од других Линукс дистрибуција, СолидИксК је одмах спреман да пушта музику, видео и још много тога.&lt;br /&gt;&lt;br /&gt;Разни програми се могу инсталирати простим кликом мишем.&lt;br /&gt;&lt;br /&gt;СолидИксК је компатибилан са већином распрострањених формата попут: docx, xlsx, doc, xls, pdf, zip, rar, mp3, mpg и многим другим.</translation>
    </message>
    <message>
        <location filename="../calamares/branding/solydxk/show.qml" line="102"/>
        <source>&lt;h3&gt;Office tools are ready to use as soon as you install SolydXK&lt;/h3&gt;&lt;br /&gt;LibreOffice, a powerful office software suite, comes built into SolydXK.&lt;br /&gt;&lt;br /&gt;LibreOffice is very easy to learn and use.&lt;br /&gt;&lt;br /&gt;You can use it to create letters, presentations and spreadsheets, as well as diagrams and databases.&lt;br /&gt;&lt;br /&gt;LibreOffice uses the standard OpenDocument format and it works with documents from other popular office applications including WordPerfect and Microsoft Office.</source>
        <translation>&lt;h3&gt;Канцеларијски алати су спремни чим инсталирате СолидИксК&lt;/h3&gt;&lt;br /&gt;Либреофис, моћан канцеларијски пакет долази уз СолидИксК.&lt;br /&gt;&lt;br /&gt;Либреофис је веома лак за учење и коришћење.&lt;br /&gt;&lt;br /&gt;Можете га користити за писање, презентације и табеларне калкулације као и за дијаграме и базе података.&lt;br /&gt;&lt;br /&gt;Либреофис користи усвојени формат отвореног документа а ради и са документима популарних канцеларијских програма попут „Ворд перфекта“ и „Мајкрософт офиса“.</translation>
    </message>
    <message>
        <location filename="../calamares/branding/solydxk/show.qml" line="123"/>
        <source>&lt;h3&gt;An alternative to mainstream operating systems&lt;/h3&gt;&lt;br /&gt;SolydXK is easy to use, powerful and configurable.&lt;br /&gt;&lt;br /&gt;SolydXK is safe and stable. Unlike other operating systems, it is not prone to computer viruses or spyware, it does not suffer from disk fragmentation, and it has no registry that requires periodic cleaning.</source>
        <translation>&lt;h3&gt;Алтернатива најраспрострањенијим оперативним системима&lt;/h3&gt;&lt;br /&gt;СолидИксК је лак за коришћење, моћан и подесив.&lt;br /&gt;&lt;br /&gt;СолидИксК је сигуран и стабилан. За разлику од других оперативних система, није подложан вирусима или спајверу, не пати од фрагментације диска и нема базу регистара која захтева периодично чишћење.</translation>
    </message>
    <message>
        <location filename="../calamares/branding/solydxk/show.qml" line="142"/>
        <source>&lt;h3&gt;Safe updates&lt;/h3&gt;&lt;br /&gt;Some operating systems make updating your system harder than it really needs to be. SolydXK thinks upgrades should be quick and easy, and then get out of the way.&lt;br /&gt;&lt;br /&gt;The Update Manager sits discreetly in your system tray and lets you know when updates are available. You don&apos;t have to apply updates when you don&apos;t want to. The Update Manager won&apos;t pop up or annoy you in any way.&lt;br /&gt;&lt;br /&gt;All updated files are maintained and closely checked by trusted developers and maintainers.&lt;br /&gt;&lt;br /&gt;All files are stored in special secure repositories for your use.&lt;br /&gt;&lt;br /&gt;The security repository is synchronized daily.</source>
        <translation>&lt;h3&gt;Сигурносне закрпе&lt;/h3&gt;&lt;br /&gt;Неки оперативни системи чине ажурирања система тежим него што би требало. СолидИксК сматра да надоградња треба да буде брза и лака и да не смета.&lt;br /&gt;&lt;br /&gt;Менаџер ажурирања чучи дискретно у системској касети и обавештава вас када су доступна ажурирања. Не морате их применити када то не желите. Менаџер ажурирања неће искакати нити вас нервирати.&lt;br /&gt;&lt;br /&gt;Сви ажурирани фајлови се одржавају и темељно проваравају од стране поузданих програмера.&lt;br /&gt;&lt;br /&gt;Сви фајлови су смештени у посебним сигурним ризницама пакета.&lt;br /&gt;&lt;br /&gt;Сигурносна ризница се синхронизује свакодневно.</translation>
    </message>
    <message>
        <location filename="../calamares/branding/solydxk/show.qml" line="164"/>
        <source>&lt;h3&gt;A great community&lt;/h3&gt;&lt;br /&gt;SolydXK users are happy to share their passion and enthusiasm and are eager to help. Don&apos;t hesitate to ask questions on the forums or to get involved in the community.&lt;br /&gt;&lt;br /&gt;Send us your feedback and tell us about your experience. We&apos;ll listen to your ideas and use them to further improve SolydXK.</source>
        <translation>&lt;h3&gt;Сјајна заједница&lt;/h3&gt;&lt;br /&gt;СолидИксК корисници радо деле своју страст и ентузијазам и желе да помогну. Не оклевајте да поставите питање на форуму нити да се придружите заједници.&lt;br /&gt;&lt;br /&gt;Пошаљите нам ваше утиске и искуства. Саслушаћемо ваше идеје и употребити их у даљем побољшавању СолидИксК-а.</translation>
    </message>
</context>
</TS>
